@@ -1,7 +1,7 @@
 from model2.role.main import RoleManager
 
 
-class GoodsAction(object):
+class RoleAction(object):
     def get(self, **params):
         if params:
             for i in params:
