@@ -1,4 +1,4 @@
-from ext import EXT_CONTEXT
+from skyext import EXT_CONTEXT
 from sqlalchemy import Column, Integer, String
 
 class User(EXT_CONTEXT["db"].Model):
